Different Methods to calculate home-range overlaps
hr_overlap(x, ...)# S3 method for hr
hr_overlap(x, y, ...)
# S3 method for list
hr_overlap(x, consecutive.only = TRUE, labels = NULL, ...)
hr A home-range estimate
Further arguments, none implemented.
[logical=TRUE] Should only consecutive overlaps be calculated or all combinations?
[character=NULL] Labels for different instances. If NULL (the default) numbers will be used.
data.frame with the isopleth level and area in units of the coordinate reference system.